Nomenclature — amplpower 0.0.0 documentation

# Nomenclature

This section provides an overview of the formulations and optimization models used in the package.

## Indexes

\(g\) | Generator index
\(\mathcal{G}_n\) | Set of generators at bus \(n\)
\(n, m\) | Bus indices
\(l\) | Transmission line index

## Parameters

\(S_{\text{base}}\) | Base power [MVA]
\(a_{g}, b_{g}, c_{g}\) | Cost coefficients for \(g\)
\(\overline{p}_g, \underline{p}_g\) | Active power generation limits for \(g\) [MW]
\(\overline{q}_g, \underline{q}_g\) | Reactive power generation limits for \(g\) [MW]
\(p^d_n, q^d_n\) | Active and reactive power demand at node \(n\) [MW, MVAr]
\(\overline{\theta}_n, \underline{\theta}_n\) | Voltage angle limits at bus \(n\) [radians]
\(\underline{v}_n, \overline{v}_n\) | Voltage magnitude limits at node \(n\) [p.u.]
\(G^{sh}_n, B^{sh}_n\) | Shunt conductance and susceptance at node \(n\) [p.u.]
\(r_l, x_l\) | Series resistance and reactance of branch \(l\) [p.u.]
\(b_l\) | Total charging susceptance of branch \(l\) [p.u.]
\(\tau_l, \gamma_l\) | Tap ratio magnitude and phase shift angle of branch \(l\)
\(\overline{s}_l\) | Apparent power flow limit for branch \(l\) [MVA]
\(F_{l,n}, T_{l,n}\) | Incidence matrices for “from” and “to” buses of line \(l\)

We also define the following parameters for the branch \(l\):

\[\begin{split}\begin{align} & G^{ff}_l + jB^{ff}_l = \left(\tfrac{1}{r_l+jx_l}+j\tfrac{b_l}{2} \right)\tfrac{1}{\tau_l^2} \\ & G^{ft}_l + jB^{ft}_l = -\tfrac{1}{r_l+jx_l}\tfrac{1}{\tau_l e^{-j\gamma_l}} \\ & G^{tf}_l + jB^{tf}_l = -\tfrac{1}{r_l+jx_l}\tfrac{1}{\tau_l e^{j\gamma_l}} \\ & G^{tt}_l + jB^{tt}_l = \left(\tfrac{1}{r_l+jx_l}+j\tfrac{b_l}{2} \right) \end{align}\end{split}\]

## Variables

\(p_g\) | Active power generation of \(g\) [MW]
\(q_g\) | Reactive power generation of \(g\) [MVAr]
\(v_n\) | Voltage magnitude at node \(n\) [p.u.]
\(\theta_n\) | Voltage angle at bus \(n\) [radians]
\(v_n^{(2)}\) | Voltage magnitude squared at node \(n\) [p.u.]
\(e_n, f_n\) | Real and imaginary parts of voltage at node \(n\) [p.u.]
\(p^f_l, p^t_l\) | Active power flow on branch \(l\) (from/to) [MW]
\(q^f_l, q^t_l\) | Reactive power flow on branch \(l\) (from/to) [MVAr]